
# WYNKER

STARTER KIT FOR FLASK WEB FRAMEWORK



## Features

- Blueprint based starter kit
- Command to Add Model
- Command to Add Blueprint



## Upcoming Features

- Pre-configured TailwindCSS
- User Authentication (Registration, Login, Forgot Password, Reset Password, etc.)